@@ -1,4 +1,4 @@
-pub mod fees;
+mod fees;
 mod msg;
 mod query;
 mod route;
@@ -12,7 +12,11 @@ pub use msg::{
     StargazeMsgWrapper,
 };
 
-pub use fees::burn_and_distribute_fee;
+pub type Response = cosmwasm_std::Response<StargazeMsgWrapper>;
+pub type SubMsg = cosmwasm_std::SubMsg<StargazeMsgWrapper>;
+pub type CosmosMsg = cosmwasm_std::CosmosMsg<StargazeMsgWrapper>;
+
+pub use fees::{burn_and_distribute_fee, FeeError};
 pub use query::StargazeQuery;
 pub use route::StargazeRoute;
 
